Package 'rk.survey.wrangling'

Title: A suite of plugins for manipulating complex survey objects using 'srvyr' and 'survey'. Includes batch transformations, recoding, and scoring within survey designs.
Description: A suite of plugins for manipulating complex survey objects using 'srvyr' and 'survey'. Includes batch transformations, recoding, and scoring within survey designs.
Authors: Alfonso Cano
Maintainer: Alfonso Cano <[email protected]>
License: GPL (>= 3)
Version: 0.1.4
Built: 2026-06-04 10:06:37 UTC
Source: https://github.com/AlfCano/rk.survey.wrangling

Help Index